@@ -52,8 +52,9 @@ enum tbf_fsm_states {
 	TBF_ST_ASSIGN,	/* wait for downlink assignment */
 	TBF_ST_FLOW,	/* RLC/MAC flow, resource needed */
 	TBF_ST_FINISHED,	/* flow finished, wait for release */
-	TBF_ST_WAIT_RELEASE,/* DL TBF: wait for release or restart */
-	TBF_ST_RELEASING,	/* releasing, wait to free TBI/USF */
+	TBF_ST_WAIT_RELEASE,	/* DL TBF: wait for release or restart */
+	TBF_ST_WAIT_REUSE_TFI,	/* DL TBF: wait to reuse TFI after last PKT ACK/NACK */
+	TBF_ST_RELEASING,	/* releasing, wait to free TFI/USF */
 };
 
 struct tbf_dl_fsm_ctx {
@@ -62,7 +63,6 @@ struct tbf_dl_fsm_ctx {
 		struct gprs_rlcmac_dl_tbf *dl_tbf;
 	};
 	uint32_t state_flags;
-	unsigned int T_release; /* Timer to be used to end release: T3169 or T3195 */
 };
 
 struct tbf_ul_fsm_ctx {
@@ -71,7 +71,6 @@ struct tbf_ul_fsm_ctx {
 		struct gprs_rlcmac_ul_tbf *ul_tbf;
 	};
 	uint32_t state_flags;
-	unsigned int T_release; /* Timer to be used to end release: T3169 or T3195 */
 };
 
 extern struct osmo_fsm tbf_dl_fsm;
